@@ -16,18 +16,19 @@
 ##
 import os, ConfigParser, hildon, gtk, string, gobject, subprocess
 from inputdialogs import *
+from help import HelpWindow
 import tracker_cfg
 
 tracker_cfg_file = os.path.expanduser('~/.config/tracker/tracker.cfg')
 backup_file = os.path.expanduser('~/.config/tracker/tracker.cfg.ORIG')
-    
+
 class TrackerPrefs(object):
   def backup(self):
     if not os.path.exists(backup_file):
       import shutil
       shutil.copy2(tracker_cfg_file, backup_file)
       return True
-  
+
   def __init__(self):
     program = hildon.Program.get_instance()
     self.window = hildon.StackableWindow()
@@ -54,7 +55,7 @@ class TrackerPrefs(object):
       if result == gtk.RESPONSE_OK:
         self.save(None)
     gtk.main_quit()
-       
+
   def setup_view(self):
     vbox1 = gtk.VBox()
     for section, option in tracker_cfg.contents:
@@ -81,7 +82,7 @@ class TrackerPrefs(object):
     self.pannable_area = hildon.PannableArea()
     self.pannable_area.add_with_viewport(vbox1)
     self.window.add(self.pannable_area)
-  
+
   def setup_menu(self):
     menu = hildon.AppMenu()
     button = gtk.Button("Save")
@@ -96,6 +97,9 @@ class TrackerPrefs(object):
     button = gtk.Button("Restart & reindex")
     button.connect("clicked", self.restart)
     menu.append(button)
+    button = gtk.Button("Help")
+    button.connect("clicked", lambda b: HelpWindow())
+    menu.append(button)
     menu.show_all()
     self.window.set_app_menu(menu)
 
@@ -107,7 +111,7 @@ class TrackerPrefs(object):
       self.window.set_title(self.window.get_title()[1:])
       self.dirty = False
       hildon.hildon_banner_show_information_with_markup(self.window, 'bajs','Tracker configuration saved')
-  
+
   def cfg_set(self, section, option, value):
     if value != self.cfg.get(section, option):
       #print '%s %s' % (option, value)
@@ -115,7 +119,7 @@ class TrackerPrefs(object):
       if not self.dirty:
         self.window.set_title('*'+self.window.get_title())
         self.dirty = True
- 
+
   def restart(self, btn):
     if btn.get_label().split()[-1]== 'reindex':
       txt = 'Are you sure you want to restart tracker and reindex content?'
@@ -124,7 +128,7 @@ class TrackerPrefs(object):
     else:
       txt = 'Are you sure you want to remove databases and restart tracker?'
       tparg = '-r'
-      tdarg = ''      
+      tdarg = ''
     note = hildon.Note('confirmation', self.window, txt)
     result = gtk.Dialog.run(note)
     note.destroy()
@@ -133,7 +137,7 @@ class TrackerPrefs(object):
       subprocess.call(['tracker-processes', tparg])
       os.system('/usr/lib/tracker/trackerd %s &' % tdarg)
       hildon.hildon_banner_show_information_with_markup(self.window, 'bajs', 'Restarted')
-   
+
   def restore(self, btn):
     note = hildon.Note('confirmation', self.window, \
     'Are you sure you want to drop all your modifications and restore the factory default configuration?')
@@ -154,7 +158,7 @@ class TrackerPrefs(object):
       self.window.remove(self.pannable_area)
       self.setup_view()
       self.window.show_all()
-      hildon.hildon_banner_show_information_with_markup(self.window,'bajs',note)    
+      hildon.hildon_banner_show_information_with_markup(self.window,'bajs',note)
 
   def show_list_dialog(self, button, section, option, cls):
     ssep = ';'
@@ -167,7 +171,7 @@ class TrackerPrefs(object):
       self.cfg_set(section, option, newstr);
       button.set_value(newstr);
     dialog.destroy()
- 
+
   def setup_openlist_dialog_button(self, cls, section, option):
     button = hildon.Button(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
@@ -178,7 +182,7 @@ class TrackerPrefs(object):
 
   def toggle_bool_property(self, button, section, option):
     self.cfg_set(section, option, string.lower(str(button.get_active())))
-  
+
   def setup_checkbutton(self, section, option):
     cb = hildon.CheckButton(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
     cb.set_label(option)
@@ -192,7 +196,7 @@ class TrackerPrefs(object):
       self.cfg_set(section, option, dialog.entry.get_text());
       button.set_value(dialog.entry.get_text());
     dialog.destroy()
-    
+
   def setup_textentry(self, section, option):
     button = hildon.Button(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
@@ -200,13 +204,13 @@ class TrackerPrefs(object):
     gtk.Button.set_alignment(button, 0.0, 0.0)
     button.connect('clicked', self.show_textentry_dialog, section, option)
     return button
-    
+
   def setup_directories_button(self, section, option):
     return self.setup_openlist_dialog_button(DirListDialog, section, option)
-    
+
   def setup_stringlist_button(self, section, option):
-    return self.setup_openlist_dialog_button(StrListDialog, section, option)    
-    
+    return self.setup_openlist_dialog_button(StrListDialog, section, option)
+
   def on_pb_value_changed(self, btn, section, option):
     self.cfg_set(section, option, btn.get_selector().get_current_text())
 
@@ -230,10 +234,10 @@ class TrackerPrefs(object):
     l = gtk.Label()
     l.set_markup('<big>%s</big>' % s)
     return l
-    
+
   def on_adj_value_changed(self, a, s, o):
     self.cfg_set(s, o, str(int(a.value)))
-    
+
   def setup_seekbar(self, s, o, r):
     sb = hildon.GtkHScale()
     sb.set_digits(0)
@@ -248,8 +252,7 @@ class TrackerPrefs(object):
     hbox.pack_start(gtk.Label(o), expand=False, padding=10)
     hbox.pack_start(sb)
     return hbox
-  
+
 if __name__=="__main__":
   prefs = TrackerPrefs()
   gtk.main()
-  
\ No newline at end of file
